#[repr(C)]pub struct ControllerGetOutputDictionaryResponse {
pub dictionary: EventPair,
}Fields
dictionary: EventPairTrait Implementations
Sourceimpl<___E> Encode<ControllerGetOutputDictionaryResponse, ___E> for ControllerGetOutputDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ControllerGetOutputDictionaryResponse, ___E> for ControllerGetOutputDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ControllerGetOutputDictionaryResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ControllerGetOutputDictionaryResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerGetOutputDictionaryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerGetOutputDictionaryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ControllerGetOutputDictionaryResponse>, ___E> for ControllerGetOutputDictionaryResponsewhere
___E: Encoder + ?Sized,
ControllerGetOutputDictionaryResponse: Encode<ControllerGetOutputDictionaryResponse, ___E>,
impl<___E> EncodeOption<Box<'static, ControllerGetOutputDictionaryResponse>, ___E> for ControllerGetOutputDictionaryResponsewhere
___E: Encoder + ?Sized,
ControllerGetOutputDictionaryResponse: Encode<ControllerGetOutputDictionaryResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ControllerGetOutputDictionaryResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ControllerGetOutputDictionaryResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ControllerGetOutputDictionaryResponse> for ControllerGetOutputDictionaryResponse
impl FromWire<ControllerGetOutputDictionaryResponse> for ControllerGetOutputDictionaryResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ControllerGetOutputDictionaryResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ControllerGetOutputDictionaryResponse, Self>
Sourcefn from_wire(wire: ControllerGetOutputDictionaryResponse) -> Self
fn from_wire(wire: ControllerGetOutputDictionaryResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ControllerGetOutputDictionaryResponse
impl PartialEq for ControllerGetOutputDictionaryResponse
Sourcefn eq(&self, other: &ControllerGetOutputDictionaryResponse) -> bool
fn eq(&self, other: &ControllerGetOutputDictionaryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ControllerGetOutputDictionaryResponse