pub struct RealmGetChildOutputDictionaryDeprecatedRequest {
pub child: ChildRef,
}Fields
child: ChildRefTrait Implementations
Sourceimpl Clone for RealmGetChildOutputDictionaryDeprecatedRequest
impl Clone for RealmGetChildOutputDictionaryDeprecatedRequest
Sourcefn clone(&self) -> RealmGetChildOutputDictionaryDeprecatedRequest
fn clone(&self) -> RealmGetChildOutputDictionaryDeprecatedRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<RealmGetChildOutputDictionaryDeprecatedRequest<'static>, ___E> for RealmGetChildOutputDictionaryDeprecatedRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<RealmGetChildOutputDictionaryDeprecatedRequest<'static>, ___E> for RealmGetChildOutputDictionaryDeprecatedRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RealmGetChildOutputDictionaryDeprecatedRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RealmGetChildOutputDictionaryDeprecatedRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, RealmGetChildOutputDictionaryDeprecatedRequest<'static>>, ___E> for RealmGetChildOutputDictionaryDeprecatedRequestwhere
___E: Encoder + ?Sized,
RealmGetChildOutputDictionaryDeprecatedRequest: Encode<RealmGetChildOutputDictionaryDeprecatedRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RealmGetChildOutputDictionaryDeprecatedRequest<'static>>, ___E> for RealmGetChildOutputDictionaryDeprecatedRequestwhere
___E: Encoder + ?Sized,
RealmGetChildOutputDictionaryDeprecatedRequest: Encode<RealmGetChildOutputDictionaryDeprecatedRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RealmGetChildOutputDictionaryDeprecatedRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RealmGetChildOutputDictionaryDeprecatedRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RealmGetChildOutputDictionaryDeprecatedRequest<'de>> for RealmGetChildOutputDictionaryDeprecatedRequest
impl<'de> FromWire<RealmGetChildOutputDictionaryDeprecatedRequest<'de>> for RealmGetChildOutputDictionaryDeprecatedRequest
Sourcefn from_wire(wire: RealmGetChildOutputDictionaryDeprecatedRequest<'de>) -> Self
fn from_wire(wire: RealmGetChildOutputDictionaryDeprecatedRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for RealmGetChildOutputDictionaryDeprecatedRequest
impl PartialEq for RealmGetChildOutputDictionaryDeprecatedRequest
Sourcefn eq(&self, other: &RealmGetChildOutputDictionaryDeprecatedRequest) -> bool
fn eq(&self, other: &RealmGetChildOutputDictionaryDeprecatedRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RealmGetChildOutputDictionaryDeprecatedRequest