pub struct RealmGetChildOutputDictionaryRequest {
pub child: ChildRef,
}Fields
child: ChildRefTrait Implementations
Sourceimpl Clone for RealmGetChildOutputDictionaryRequest
impl Clone for RealmGetChildOutputDictionaryRequest
Sourcefn clone(&self) -> RealmGetChildOutputDictionaryRequest
fn clone(&self) -> RealmGetChildOutputDictionaryRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<RealmGetChildOutputDictionaryRequest<'static>, ___E> for RealmGetChildOutputDictionaryRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<RealmGetChildOutputDictionaryRequest<'static>, ___E> for RealmGetChildOutputDictionaryRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RealmGetChildOutputDictionaryRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RealmGetChildOutputDictionaryRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, RealmGetChildOutputDictionaryRequest<'static>>, ___E> for RealmGetChildOutputDictionaryRequestwhere
___E: Encoder + ?Sized,
RealmGetChildOutputDictionaryRequest: Encode<RealmGetChildOutputDictionaryRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RealmGetChildOutputDictionaryRequest<'static>>, ___E> for RealmGetChildOutputDictionaryRequestwhere
___E: Encoder + ?Sized,
RealmGetChildOutputDictionaryRequest: Encode<RealmGetChildOutputDictionaryRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RealmGetChildOutputDictionaryRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RealmGetChildOutputDictionaryRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RealmGetChildOutputDictionaryRequest<'de>> for RealmGetChildOutputDictionaryRequest
impl<'de> FromWire<RealmGetChildOutputDictionaryRequest<'de>> for RealmGetChildOutputDictionaryRequest
Sourcefn from_wire(wire: RealmGetChildOutputDictionaryRequest<'de>) -> Self
fn from_wire(wire: RealmGetChildOutputDictionaryRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for RealmGetChildOutputDictionaryRequest
impl PartialEq for RealmGetChildOutputDictionaryRequest
Sourcefn eq(&self, other: &RealmGetChildOutputDictionaryRequest) -> bool
fn eq(&self, other: &RealmGetChildOutputDictionaryRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RealmGetChildOutputDictionaryRequest