pub struct Realm;Expand description
The type corresponding to the Realm protocol. A protocol used by a component instance to manage its own realm, such as for binding to its children.
Requests to this protocol are processed in the order they are received. Clients that wish to send requests in parallel should open multiple connections.
The component framework provides this service to components that use
fuchsia.component.Realm.