ChildIteratorLocalServerHandler

Trait ChildIteratorLocalServerHandler 

pub trait ChildIteratorLocalServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn next( &mut self, responder: Responder<Next, ___T>, ) -> impl Future<Output = ()>; }
A server handler for the ChildIterator protocol.

See ChildIterator for more details.

Required Methods

fn next(&mut self, responder: Responder<Next, ___T>) -> impl Future<Output = ()>

Advance the iterator and return the next batch of children.

Returns a vector of ChildRef. Returns an empty vector when there are no more children.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> ChildIteratorLocalServerHandler<___T> for Local<___H>
where ___H: ChildIteratorServerHandler<___T>, ___T: Transport,

Source

async fn next(&mut self, responder: Responder<Next, ___T>)

Implementors