ExecutionControllerLocalClientHandler

Trait ExecutionControllerLocalClientHandler 

pub trait ExecutionControllerLocalClientHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn on_stop( &mut self, request: Request<OnStop, ___T>, ) -> impl Future<Output = ()>; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> { ... } }
A client handler for the ExecutionController protocol.

See ExecutionController for more details.

Required Methods

fn on_stop( &mut self, request: Request<OnStop, ___T>, ) -> impl Future<Output = ()>

When the child is stopped due to Stop being called, the child exiting on its own, or for any other reason, OnStop is called and then this channel is closed.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> ExecutionControllerLocalClientHandler<___T> for Local<___H>
where ___H: ExecutionControllerClientHandler<___T>, ___T: Transport,

Source

async fn on_stop(&mut self, request: Request<OnStop, ___T>)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors