#[repr(C)]pub struct ChildIteratorNextResponse<'de> {
pub children: Vector<'de, ChildRef<'de>>,
}Expand description
The wire type corresponding to ChildIteratorNextResponse.
Fields
children: Vector<'de, ChildRef<'de>>Trait Implementations
Sourceimpl Constrained for ChildIteratorNextResponse<'_>
impl Constrained for ChildIteratorNextResponse<'_>
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ChildIteratorNextResponse<'_>>,
_: <ChildIteratorNextResponse<'_> as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ChildIteratorNextResponse<'_>>, _: <ChildIteratorNextResponse<'_> as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<'de> Debug for ChildIteratorNextResponse<'de>
impl<'de> Debug for ChildIteratorNextResponse<'de>
Sourceimpl<'de, ___D> Decode<___D> for ChildIteratorNextResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
impl<'de, ___D> Decode<___D> for ChildIteratorNextResponse<'de>where
___D: InternalHandleDecoder + Decoder<'de> + ?Sized,
Sourceimpl<'a, ___E> Encode<ChildIteratorNextResponse<'static>, ___E> for &'a ChildIteratorNextResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<ChildIteratorNextResponse<'static>, ___E> for &'a ChildIteratorNextResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ChildIteratorNextResponse<'static>, ___E> for ChildIteratorNextResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<ChildIteratorNextResponse<'static>, ___E> for ChildIteratorNextResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<ChildIteratorNextResponse<'static>, ___E> for ChildIteratorNextResponse<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, ChildRef<'static>>, ___E>,
impl<___E, T0> Encode<ChildIteratorNextResponse<'static>, ___E> for ChildIteratorNextResponse<T0>where
___E: InternalHandleEncoder + Encoder + ?Sized,
T0: Encode<Vector<'static, ChildRef<'static>>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ChildIteratorNextResponse<'de>> for ChildIteratorNextResponse
impl<'de> FromWire<ChildIteratorNextResponse<'de>> for ChildIteratorNextResponse
Sourcefn from_wire(wire: ChildIteratorNextResponse<'de>) -> ChildIteratorNextResponse
fn from_wire(wire: ChildIteratorNextResponse<'de>) -> ChildIteratorNextResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ChildIteratorNextResponse<'de>> for ChildIteratorNextResponse
impl<'de> FromWireRef<ChildIteratorNextResponse<'de>> for ChildIteratorNextResponse
Sourcefn from_wire_ref(
wire: &ChildIteratorNextResponse<'de>,
) -> ChildIteratorNextResponse
fn from_wire_ref( wire: &ChildIteratorNextResponse<'de>, ) -> ChildIteratorNextResponse
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for ChildIteratorNextResponse<'de>
impl<'de> IntoNatural for ChildIteratorNextResponse<'de>
Sourcetype Natural = ChildIteratorNextResponse
type Natural = ChildIteratorNextResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ChildIteratorNextResponse<'static>
impl Wire for ChildIteratorNextResponse<'static>
Sourcetype Narrowed<'de> = ChildIteratorNextResponse<'de>
type Narrowed<'de> = ChildIteratorNextResponse<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>)
fn zero_padding(out_: &mut MaybeUninit<ChildIteratorNextResponse<'static>>)
Writes zeroes to the padding for this type, if any.