#[repr(C)]pub struct ControllerGetExposedDictionaryResponse {
pub dictionary: DictionaryRef,
}Expand description
The wire type corresponding to ControllerGetExposedDictionaryResponse.
Fields
dictionary: DictionaryRefTrait Implementations
Sourceimpl Constrained for ControllerGetExposedDictionaryResponse
impl Constrained for ControllerGetExposedDictionaryResponse
Sourceimpl<___D> Decode<___D> for ControllerGetExposedDictionaryResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ControllerGetExposedDictionaryResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ControllerGetExposedDictionaryResponse, ___E> for ControllerGetExposedDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ControllerGetExposedDictionaryResponse, ___E> for ControllerGetExposedDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ControllerGetExposedDictionaryResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ControllerGetExposedDictionaryResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerGetExposedDictionaryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerGetExposedDictionaryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ControllerGetExposedDictionaryResponse, ___E> for ControllerGetExposedDictionaryResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DictionaryRef, ___E>,
impl<___E, T0> Encode<ControllerGetExposedDictionaryResponse, ___E> for ControllerGetExposedDictionaryResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<DictionaryRef, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerGetExposedDictionaryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerGetExposedDictionaryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ControllerGetExposedDictionaryResponse> for ControllerGetExposedDictionaryResponse
impl FromWire<ControllerGetExposedDictionaryResponse> for ControllerGetExposedDictionaryResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ControllerGetExposedDictionaryResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ControllerGetExposedDictionaryResponse, Self>
Sourcefn from_wire(wire: ControllerGetExposedDictionaryResponse) -> Self
fn from_wire(wire: ControllerGetExposedDictionaryResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ControllerGetExposedDictionaryResponse
impl IntoNatural for ControllerGetExposedDictionaryResponse
Sourcetype Natural = ControllerGetExposedDictionaryResponse
type Natural = ControllerGetExposedDictionaryResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ControllerGetExposedDictionaryResponse
impl Wire for ControllerGetExposedDictionaryResponse
Sourcetype Narrowed<'de> = ControllerGetExposedDictionaryResponse
type Narrowed<'de> = ControllerGetExposedDictionaryResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.