#[repr(C)]pub struct ControllerIsStartedResponse {
pub is_started: bool,
}Expand description
The wire type corresponding to ControllerIsStartedResponse.
Fields
is_started: boolTrait Implementations
Sourceimpl Constrained for ControllerIsStartedResponse
impl Constrained for ControllerIsStartedResponse
Sourceimpl Debug for ControllerIsStartedResponse
impl Debug for ControllerIsStartedResponse
Sourceimpl<___D> Decode<___D> for ControllerIsStartedResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ControllerIsStartedResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ControllerIsStartedResponse, ___E> for ControllerIsStartedResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ControllerIsStartedResponse, ___E> for ControllerIsStartedResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ControllerIsStartedResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, ControllerIsStartedResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerIsStartedResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerIsStartedResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ControllerIsStartedResponse, ___E> for ControllerIsStartedResponse<T0>
impl<___E, T0> Encode<ControllerIsStartedResponse, ___E> for ControllerIsStartedResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ControllerIsStartedResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ControllerIsStartedResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ControllerIsStartedResponse> for ControllerIsStartedResponse
impl FromWire<ControllerIsStartedResponse> for ControllerIsStartedResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ControllerIsStartedResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<ControllerIsStartedResponse, Self>
Sourcefn from_wire(wire: ControllerIsStartedResponse) -> Self
fn from_wire(wire: ControllerIsStartedResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ControllerIsStartedResponse
impl IntoNatural for ControllerIsStartedResponse
Sourcetype Natural = ControllerIsStartedResponse
type Natural = ControllerIsStartedResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ControllerIsStartedResponse
impl Wire for ControllerIsStartedResponse
Sourcetype Narrowed<'de> = ControllerIsStartedResponse
type Narrowed<'de> = ControllerIsStartedResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.