#[repr(C)]pub struct RealmGetChildOutputDictionaryResponse {
pub dictionary: EventPair,
}Expand description
The wire type corresponding to RealmGetChildOutputDictionaryResponse.
Fields
dictionary: EventPairTrait Implementations
Sourceimpl Constrained for RealmGetChildOutputDictionaryResponse
impl Constrained for RealmGetChildOutputDictionaryResponse
Sourceimpl<___D> Decode<___D> for RealmGetChildOutputDictionaryResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for RealmGetChildOutputDictionaryResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<RealmGetChildOutputDictionaryResponse, ___E> for RealmGetChildOutputDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<RealmGetChildOutputDictionaryResponse, ___E> for RealmGetChildOutputDictionaryResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, RealmGetChildOutputDictionaryResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, RealmGetChildOutputDictionaryResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RealmGetChildOutputDictionaryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RealmGetChildOutputDictionaryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<RealmGetChildOutputDictionaryResponse, ___E> for RealmGetChildOutputDictionaryResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<RealmGetChildOutputDictionaryResponse, ___E> for RealmGetChildOutputDictionaryResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RealmGetChildOutputDictionaryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RealmGetChildOutputDictionaryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<RealmGetChildOutputDictionaryResponse> for RealmGetChildOutputDictionaryResponse
impl FromWire<RealmGetChildOutputDictionaryResponse> for RealmGetChildOutputDictionaryResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<RealmGetChildOutputDictionaryResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<RealmGetChildOutputDictionaryResponse, Self>
Sourcefn from_wire(wire: RealmGetChildOutputDictionaryResponse) -> Self
fn from_wire(wire: RealmGetChildOutputDictionaryResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for RealmGetChildOutputDictionaryResponse
impl IntoNatural for RealmGetChildOutputDictionaryResponse
Sourcetype Natural = RealmGetChildOutputDictionaryResponse
type Natural = RealmGetChildOutputDictionaryResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for RealmGetChildOutputDictionaryResponse
impl Wire for RealmGetChildOutputDictionaryResponse
Sourcetype Narrowed<'de> = RealmGetChildOutputDictionaryResponse
type Narrowed<'de> = RealmGetChildOutputDictionaryResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.