IntrospectorLocalServerHandler

Trait IntrospectorLocalServerHandler 

pub trait IntrospectorLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn get_moniker(
        &mut self,
        request: Request<GetMoniker, ___T>,
        responder: Responder<GetMoniker, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the Introspector protocol.

See Introspector for more details.

Required Methods

fn get_moniker( &mut self, request: Request<GetMoniker, ___T>, responder: Responder<GetMoniker, ___T>, ) -> impl Future<Output = ()>

Obtains the moniker relative to this realm of the component corresponding to the provided token. Runners may obtain the token via fuchsia.component.runner/ComponentStartInfo.component_instance.

Returns Error.INSTANCE_NOT_FOUND if the token is invalid, or does not correspond to a component under this realm.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> IntrospectorLocalServerHandler<___T> for Local<___H>
where ___H: IntrospectorServerHandler<___T>, ___T: Transport,

Source

async fn get_moniker( &mut self, request: Request<GetMoniker, ___T>, responder: Responder<GetMoniker, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors